@@ -18,8 +18,8 @@
 
 #define G_LOG_DOMAIN "ide-buffer"
 
-#include <egg-counter.h>
-#include <egg-signal-group.h>
+#include <dazzle.h>
+#include <dazzle.h>
 #include <glib/gi18n.h>
 #include <gspell/gspell.h>
 
@@ -73,7 +73,7 @@ typedef struct
   IdeContext             *context;
   IdeDiagnostics         *diagnostics;
   GHashTable             *diagnostics_line_cache;
-  EggSignalGroup         *diagnostics_manager_signals;
+  DzlSignalGroup         *diagnostics_manager_signals;
   IdeFile                *file;
   GBytes                 *content;
   IdeBufferChangeMonitor *change_monitor;
@@ -84,7 +84,7 @@ typedef struct
   GspellChecker          *spellchecker;
   gchar                  *title;
 
-  EggSignalGroup         *file_signals;
+  DzlSignalGroup         *file_signals;
 
   GFileMonitor           *file_monitor;
 
@@ -110,7 +110,7 @@ typedef struct
 
 G_DEFINE_TYPE_WITH_PRIVATE (IdeBuffer, ide_buffer, GTK_SOURCE_TYPE_BUFFER)
 
-EGG_DEFINE_COUNTER (instances, "IdeBuffer", "Instances", "Number of IdeBuffer instances.")
+DZL_DEFINE_COUNTER (instances, "IdeBuffer", "Instances", "Number of IdeBuffer instances.")
 
 enum {
   PROP_0,
@@ -297,7 +297,7 @@ ide_buffer_set_context (IdeBuffer  *self,
 
   diagnostics_manager = ide_context_get_diagnostics_manager (context);
 
-  egg_signal_group_set_target (priv->diagnostics_manager_signals, diagnostics_manager);
+  dzl_signal_group_set_target (priv->diagnostics_manager_signals, diagnostics_manager);
 }
 
 void
@@ -331,16 +331,16 @@ ide_buffer_clear_diagnostics (IdeBuffer *self)
   table = gtk_text_buffer_get_tag_table (buffer);
 
   if (NULL != (tag = gtk_text_tag_table_lookup (table, TAG_NOTE)))
-    ide_gtk_text_buffer_remove_tag (buffer, tag, &begin, &end, TRUE);
+    dzl_gtk_text_buffer_remove_tag (buffer, tag, &begin, &end, TRUE);
 
   if (NULL != (tag = gtk_text_tag_table_lookup (table, TAG_WARNING)))
-    ide_gtk_text_buffer_remove_tag (buffer, tag, &begin, &end, TRUE);
+    dzl_gtk_text_buffer_remove_tag (buffer, tag, &begin, &end, TRUE);
 
   if (NULL != (tag = gtk_text_tag_table_lookup (table, TAG_DEPRECATED)))
-    ide_gtk_text_buffer_remove_tag (buffer, tag, &begin, &end, TRUE);
+    dzl_gtk_text_buffer_remove_tag (buffer, tag, &begin, &end, TRUE);
 
   if (NULL != (tag = gtk_text_tag_table_lookup (table, TAG_ERROR)))
-    ide_gtk_text_buffer_remove_tag (buffer, tag, &begin, &end, TRUE);
+    dzl_gtk_text_buffer_remove_tag (buffer, tag, &begin, &end, TRUE);
 }
 
 static void
@@ -617,7 +617,7 @@ ide_buffer_reload_change_monitor (IdeBuffer *self)
       g_clear_object (&priv->change_monitor);
     }
 
-  if (priv->context && priv->file)
+  if (!priv->loading && priv->context && priv->file)
     {
       IdeVcs *vcs;
 
@@ -1073,6 +1073,9 @@ ide_buffer_loaded (IdeBuffer *self)
   if (priv->change_monitor != NULL)
     ide_buffer_change_monitor_reload (priv->change_monitor);
 
+  /* This is suspended until we've loaded */
+  ide_highlight_engine_unpause (priv->highlight_engine);
+
   IDE_EXIT;
 }
 
@@ -1225,6 +1228,7 @@ ide_buffer_constructed (GObject *object)
                            G_CONNECT_SWAPPED);
 
   priv->highlight_engine = ide_highlight_engine_new (self);
+  ide_highlight_engine_pause (priv->highlight_engine);
 
   priv->formatter_adapter = ide_extension_adapter_new (priv->context,
                                                        NULL,
@@ -1283,6 +1287,19 @@ ide_buffer_dispose (GObject *object)
 
   IDE_ENTRY;
 
+  if (priv->reclamation_handler != 0)
+    {
+      g_source_remove (priv->reclamation_handler);
+      priv->reclamation_handler = 0;
+    }
+
+  if (priv->context != NULL)
+    {
+      IdeBufferManager *buffer_manager = ide_context_get_buffer_manager (priv->context);
+
+      _ide_buffer_manager_reclaim (buffer_manager, self);
+    }
+
   if (priv->check_modified_timeout != 0)
     {
       g_source_remove (priv->check_modified_timeout);
@@ -1306,7 +1323,7 @@ ide_buffer_dispose (GObject *object)
       g_clear_object (&priv->change_monitor);
     }
 
-  egg_signal_group_set_target (priv->diagnostics_manager_signals, NULL);
+  dzl_signal_group_set_target (priv->diagnostics_manager_signals, NULL);
 
   g_clear_pointer (&priv->diagnostics_line_cache, g_hash_table_unref);
   g_clear_pointer (&priv->diagnostics, ide_diagnostics_unref);
@@ -1318,14 +1335,6 @@ ide_buffer_dispose (GObject *object)
   g_clear_object (&priv->symbol_resolver_adapter);
   g_clear_object (&priv->spellchecker);
 
-  if (priv->context != NULL)
-    {
-      g_object_weak_unref (G_OBJECT (priv->context),
-                           ide_buffer_release_context,
-                           self);
-      priv->context = NULL;
-    }
-
   G_OBJECT_CLASS (ide_buffer_parent_class)->dispose (object);
 
   IDE_EXIT;
@@ -1339,17 +1348,17 @@ ide_buffer_finalize (GObject *object)
 
   IDE_ENTRY;
 
-  if (priv->reclamation_handler != 0)
+  if (priv->context != NULL)
     {
-      g_source_remove (priv->reclamation_handler);
-      priv->reclamation_handler = 0;
+      g_object_weak_unref (G_OBJECT (priv->context),
+                           ide_buffer_release_context,
+                           self);
+      priv->context = NULL;
     }
 
-  ide_clear_weak_pointer (&priv->context);
-
   G_OBJECT_CLASS (ide_buffer_parent_class)->finalize (object);
 
-  EGG_COUNTER_DEC (instances);
+  DZL_COUNTER_DEC (instances);
 
   IDE_EXIT;
 }
@@ -1616,15 +1625,17 @@ ide_buffer_init (IdeBuffer *self)
 
   IDE_ENTRY;
 
+  priv->loading = TRUE;
+
   priv->highlight_diagnostics = TRUE;
 
-  priv->file_signals = egg_signal_group_new (IDE_TYPE_FILE);
-  egg_signal_group_connect_object (priv->file_signals,
+  priv->file_signals = dzl_signal_group_new (IDE_TYPE_FILE);
+  dzl_signal_group_connect_object (priv->file_signals,
                                    "notify::language",
                                    G_CALLBACK (ide_buffer__file_notify_language),
                                    self,
                                    G_CONNECT_SWAPPED);
-  egg_signal_group_connect_object (priv->file_signals,
+  dzl_signal_group_connect_object (priv->file_signals,
                                    "notify::file",
                                    G_CALLBACK (ide_buffer__file_notify_file),
                                    self,
@@ -1632,14 +1643,14 @@ ide_buffer_init (IdeBuffer *self)
 
   priv->diagnostics_line_cache = g_hash_table_new (g_direct_hash, g_direct_equal);
 
-  priv->diagnostics_manager_signals = egg_signal_group_new (IDE_TYPE_DIAGNOSTICS_MANAGER);
-  egg_signal_group_connect_object (priv->diagnostics_manager_signals,
+  priv->diagnostics_manager_signals = dzl_signal_group_new (IDE_TYPE_DIAGNOSTICS_MANAGER);
+  dzl_signal_group_connect_object (priv->diagnostics_manager_signals,
                                    "changed",
                                    G_CALLBACK (ide_buffer__diagnostics_manager__changed),
                                    self,
                                    G_CONNECT_SWAPPED);
 
-  EGG_COUNTER_INC (instances);
+  DZL_COUNTER_INC (instances);
 
   IDE_EXIT;
 }
@@ -1708,7 +1719,7 @@ ide_buffer_set_file (IdeBuffer *self,
 
   if (g_set_object (&priv->file, file))
     {
-      egg_signal_group_set_target (priv->file_signals, file);
+      dzl_signal_group_set_target (priv->file_signals, file);
       ide_file_load_settings_async (priv->file,
                                     NULL,
                                     ide_buffer__file_load_settings_cb,
@@ -2438,7 +2449,7 @@ ide_buffer_rehighlight (IdeBuffer *self)
   g_return_if_fail (IDE_IS_BUFFER (self));
 
   /* In case we are disposing */
-  if (priv->highlight_engine == NULL)
+  if (priv->highlight_engine == NULL || priv->loading)
     IDE_EXIT;
 
   if (gtk_source_buffer_get_highlight_syntax (GTK_SOURCE_BUFFER (self)))
