@@ -18,6 +18,7 @@
 
 #define G_LOG_DOMAIN "ide-spell-check-widget"
 
+#include <dazzle.h>
 #include <glib/gi18n.h>
 #include <gspell/gspell.h>
 
@@ -525,7 +526,7 @@ ide_editor_spell_widget__key_press_event_cb (IdeEditorSpellWidget *self,
   switch (event->keyval)
     {
     case GDK_KEY_Escape:
-      ide_widget_action (GTK_WIDGET (self->view),
+      dzl_gtk_widget_action (GTK_WIDGET (self->view),
                          "frame", "show-spellcheck",
                          g_variant_new_int32 (0));
       return GDK_EVENT_STOP;
