@@ -191,6 +191,19 @@ ide_workbench_delete_event (GtkWidget   *widget,
   return GDK_EVENT_PROPAGATE;
 }
 
+static void
+ide_workbench_grab_focus (GtkWidget *widget)
+{
+  IdeWorkbench *self = (IdeWorkbench *)widget;
+  GtkWidget *child;
+
+  g_assert (IDE_IS_WORKBENCH (self));
+
+  child = gtk_stack_get_visible_child (self->perspectives_stack);
+  if (child != NULL)
+    gtk_widget_grab_focus (child);
+}
+
 static void
 ide_workbench_constructed (GObject *object)
 {
@@ -299,6 +312,7 @@ ide_workbench_class_init (IdeWorkbenchClass *klass)
   object_class->get_property = ide_workbench_get_property;
   object_class->set_property = ide_workbench_set_property;
 
+  widget_class->grab_focus = ide_workbench_grab_focus;
   widget_class->delete_event = ide_workbench_delete_event;
 
   /**
@@ -372,7 +386,7 @@ ide_workbench_class_init (IdeWorkbenchClass *klass)
     g_signal_new_class_handler ("action",
                                 G_TYPE_FROM_CLASS (klass),
                                 G_SIGNAL_RUN_FIRST | G_SIGNAL_ACTION,
-                                G_CALLBACK (ide_widget_action_with_string),
+                                G_CALLBACK (dzl_gtk_widget_action_with_string),
                                 NULL, NULL, NULL,
                                 G_TYPE_NONE,
                                 3,
@@ -528,14 +542,37 @@ ide_workbench_get_context (IdeWorkbench *self)
   return self->context;
 }
 
+static void
+ide_workbench_restore_perspectives (IdePerspective *perspective,
+                                    IdeWorkbench   *self)
+{
+  g_assert (IDE_IS_PERSPECTIVE (perspective));
+  g_assert (IDE_IS_WORKBENCH (self));
+
+  ide_perspective_restore_state (perspective);
+}
+
 static gboolean
 restore_in_timeout (gpointer data)
 {
-  g_autoptr(IdeContext) context = data;
+  g_autoptr(IdeWorkbench) self = data;
 
-  g_assert (IDE_IS_CONTEXT (context));
+  g_assert (IDE_IS_WORKBENCH (self));
 
-  ide_context_restore_async (context, NULL, NULL, NULL);
+  if (self->context != NULL)
+    {
+      g_autoptr(GSettings) settings = NULL;
+
+      /* Ask perspectives to restore state */
+      gtk_container_foreach (GTK_CONTAINER (self->perspectives_stack),
+                             (GtkCallback) ide_workbench_restore_perspectives,
+                             self);
+
+      /* Restore previous files when needed */
+      settings = g_settings_new ("org.gnome.builder");
+      if (g_settings_get_boolean (settings, "restore-previous-files"))
+        ide_context_restore_async (self->context, NULL, NULL, NULL);
+    }
 
   return G_SOURCE_REMOVE;
 }
@@ -572,11 +609,11 @@ void
 ide_workbench_set_context (IdeWorkbench *self,
                            IdeContext   *context)
 {
-  g_autoptr(GSettings) settings = NULL;
   IdeBuildManager *build_manager;
   IdeRunManager *run_manager;
   IdeProject *project;
   guint delay_msec;
+  guint duration = 0;
 
   IDE_ENTRY;
 
@@ -584,8 +621,6 @@ ide_workbench_set_context (IdeWorkbench *self,
   g_return_if_fail (IDE_IS_CONTEXT (context));
   g_return_if_fail (self->context == NULL);
 
-  settings = g_settings_new ("org.gnome.builder");
-
   g_set_object (&self->context, context);
 
   project = ide_context_get_project (context);
@@ -636,14 +671,9 @@ ide_workbench_set_context (IdeWorkbench *self,
    * the stack transition results in non-smooth transitions. So instead,
    * we will delay until the transition has completed.
    */
-  if (g_settings_get_boolean (settings, "restore-previous-files"))
-    {
-      guint duration = 0;
-
-      if (!self->disable_greeter)
-        duration = gtk_stack_get_transition_duration (self->perspectives_stack);
-      g_timeout_add (delay_msec + duration, restore_in_timeout, g_object_ref (context));
-    }
+  if (!self->disable_greeter)
+    delay_msec = gtk_stack_get_transition_duration (self->perspectives_stack);
+  g_timeout_add (delay_msec + duration, restore_in_timeout, g_object_ref (self));
 
   IDE_EXIT;
 }
@@ -941,7 +971,7 @@ ide_workbench_show_parents (GtkWidget *widget)
   parent = gtk_widget_get_parent (widget);
 
   if (IDE_IS_LAYOUT_PANE (widget))
-    pnl_dock_revealer_set_reveal_child (PNL_DOCK_REVEALER (widget), TRUE);
+    dzl_dock_revealer_set_reveal_child (DZL_DOCK_REVEALER (widget), TRUE);
 
   if (IDE_IS_PERSPECTIVE (widget))
     ide_workbench_set_visible_perspective (ide_widget_get_workbench (widget),
