@@ -19,7 +19,7 @@
 #ifndef IDE_CLANG_SYMBOL_RESOLVER_H
 #define IDE_CLANG_SYMBOL_RESOLVER_H
 
-#include "ide-symbol-resolver.h"
+#include <ide.h>
 
 G_BEGIN_DECLS
 
