@@ -174,7 +174,7 @@ init_dock (GbColorPickerWorkbenchAddin *self)
 
   g_assert (GB_IS_COLOR_PICKER_WORKBENCH_ADDIN (self));
 
-  self->dock = g_object_new (PNL_TYPE_DOCK_WIDGET,
+  self->dock = g_object_new (DZL_TYPE_DOCK_WIDGET,
                              "title", _("Colors"),
                              "expand", TRUE,
                              "visible", TRUE,
