@@ -16,6 +16,8 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+#define G_LOG_DOMAIN "gbp-devhelp-editor-view-addin"
+
 #include "gbp-devhelp-editor-view-addin.h"
 #include "gbp-devhelp-panel.h"
 
@@ -45,8 +47,8 @@ request_documentation_cb (GbpDevhelpEditorViewAddin *self,
   if (layout == NULL)
     return;
 
-  pane = pnl_dock_bin_get_right_edge (PNL_DOCK_BIN (layout));
-  panel = ide_widget_find_child_typed (pane, GBP_TYPE_DEVHELP_PANEL);
+  pane = dzl_dock_bin_get_right_edge (DZL_DOCK_BIN (layout));
+  panel = dzl_gtk_widget_find_child_typed (pane, GBP_TYPE_DEVHELP_PANEL);
   gbp_devhelp_panel_focus_search (GBP_DEVHELP_PANEL (panel), word);
 }
 
