@@ -36,7 +36,6 @@ struct _GbpFlatpakConfigurationProvider
 {
   GObject                  parent_instance;
   IdeConfigurationManager *manager;
-  GCancellable            *cancellable;
   GPtrArray               *configurations;
   GPtrArray               *manifest_monitors;
 
@@ -45,8 +44,6 @@ struct _GbpFlatpakConfigurationProvider
 };
 
 static void configuration_provider_iface_init         (IdeConfigurationProviderInterface  *iface);
-static void gbp_flatpak_configuration_provider_load   (IdeConfigurationProvider           *provider,
-                                                       IdeConfigurationManager            *manager);
 static void gbp_flatpak_configuration_provider_unload (IdeConfigurationProvider           *provider,
                                                        IdeConfigurationManager            *manager);
 
@@ -398,9 +395,12 @@ gbp_flatpak_configuration_provider_save_worker (GTask        *task,
                   if (!config_opts_replaced && new_config_opts != NULL)
                     {
                       gchar *previous_line;
+                      gchar *new_line;
 
-                      previous_line = (gchar *)g_ptr_array_remove_index (new_lines, new_lines->len - 1);
-                      g_ptr_array_add (new_lines, g_strdup_printf ("%s,", previous_line));
+                      previous_line = (gchar *)g_ptr_array_index (new_lines, new_lines->len - 1);
+                      new_line = g_strdup_printf ("%s,", previous_line);
+                      g_ptr_array_remove_index (new_lines, new_lines->len - 1);
+                      g_ptr_array_add (new_lines, new_line);
                       right_curly_brace_line = line;
                       line = g_strdup_printf ("%s\"config-opts\": []", primary_module_indent);
                     }
@@ -411,6 +411,7 @@ gbp_flatpak_configuration_provider_save_worker (GTask        *task,
               if (g_match_info_matches (match_info) || in_config_opts_array)
                 {
                   gchar *right_bracket;
+                  gchar *next_line;
 
                   right_bracket = g_strstr_len (line, -1, "]");
                   if (g_match_info_matches (match_info))
@@ -453,13 +454,25 @@ gbp_flatpak_configuration_provider_save_worker (GTask        *task,
                       continue;
                     }
 
+                  /* Check if we're on the last line of the module */
+                  next_line = g_data_input_stream_read_line_utf8 (data_stream, NULL, NULL, &error);
+                  if (error != NULL)
+                    {
+                      g_task_return_error (task, error);
+                      IDE_EXIT;
+                    }
+                  if (g_str_has_prefix (next_line, primary_module_right_curly_brace))
+                    right_curly_brace_line = next_line;
+
                   /* At this point it's either a single line or we're on the last line */
                   in_config_opts_array = FALSE;
                   config_opts_replaced = TRUE;
                   if (new_config_opts == NULL)
                     {
-                      g_free (line);
-                      line = g_strdup_printf ("%s],", array_prefix);
+                      if (right_curly_brace_line == NULL)
+                        g_ptr_array_add (new_lines, g_strdup_printf ("%s],", array_prefix));
+                      else
+                        g_ptr_array_add (new_lines, g_strdup_printf ("%s]", array_prefix));
                     }
                   else
                     {
@@ -491,14 +504,31 @@ gbp_flatpak_configuration_provider_save_worker (GTask        *task,
                           g_ptr_array_add (config_opts_subset, NULL);
                           opts_this_line = g_strjoinv ("\", \"", (gchar **)config_opts_subset->pdata);
 
-                          new_line = g_strdup_printf ("%s\"%s\"%s,", prefix, opts_this_line, suffix);
+                          if (suffix == array_suffix && right_curly_brace_line != NULL)
+                            new_line = g_strdup_printf ("%s\"%s\"%s", prefix, opts_this_line, suffix);
+                          else
+                            new_line = g_strdup_printf ("%s\"%s\"%s,", prefix, opts_this_line, suffix);
+
                           g_ptr_array_add (new_lines, new_line);
                         }
-
-                      /* Discard the line that was just replaced with the new config-opts array */
-                      g_free (line);
-                      continue;
                     }
+
+                  /* Discard the line that was just replaced with the new config-opts array */
+                  g_free (line);
+
+                  /* If we're on the last line of the module, add the curly brace now */
+                  if (right_curly_brace_line != NULL)
+                    {
+                      g_ptr_array_add (new_lines, right_curly_brace_line);
+                      right_curly_brace_line = NULL;
+                    }
+
+                  /* If the next line isn't a curly brace, add it since we already read it */
+                  if (next_line != NULL &&
+                      !g_str_has_prefix (next_line, primary_module_right_curly_brace))
+                    g_ptr_array_add (new_lines, next_line);
+
+                  continue;
                 }
             }
 
@@ -966,16 +996,18 @@ gbp_flatpak_configuration_provider_load_cb (GObject      *object,
   GPtrArray *ret;
   GError *error = NULL;
   guint i;
+  g_autoptr(GTask) task = user_data;
 
   IDE_ENTRY;
 
   g_assert (GBP_IS_FLATPAK_CONFIGURATION_PROVIDER (self));
   g_assert (G_IS_TASK (result));
+  g_assert (G_IS_TASK (task));
 
   if (!(ret = g_task_propagate_pointer (G_TASK (result), &error)))
     {
       g_warning ("%s", error->message);
-      g_clear_error (&error);
+      g_task_return_error (task, g_steal_pointer (&error));
       IDE_EXIT;
     }
 
@@ -989,33 +1021,52 @@ gbp_flatpak_configuration_provider_load_cb (GObject      *object,
 
   self->configurations = ret;
 
+  g_task_return_boolean (task, TRUE);
+
   IDE_EXIT;
 }
 
 static void
-gbp_flatpak_configuration_provider_load (IdeConfigurationProvider *provider,
-                                         IdeConfigurationManager  *manager)
+gbp_flatpak_configuration_provider_load_async (IdeConfigurationProvider *provider,
+                                               IdeConfigurationManager  *manager,
+                                               GCancellable             *cancellable,
+                                               GAsyncReadyCallback       callback,
+                                               gpointer                  user_data)
 {
   GbpFlatpakConfigurationProvider *self = (GbpFlatpakConfigurationProvider *)provider;
+  g_autoptr(GTask) parent_task = NULL;
   g_autoptr(GTask) task = NULL;
 
   IDE_ENTRY;
 
   g_assert (GBP_IS_FLATPAK_CONFIGURATION_PROVIDER (self));
   g_assert (IDE_IS_CONFIGURATION_MANAGER (manager));
+  g_assert (!cancellable || G_IS_CANCELLABLE (cancellable));
 
   ide_set_weak_pointer (&self->manager, manager);
 
   self->manifest_monitors = g_ptr_array_new_with_free_func (g_object_unref);
 
-  self->cancellable = g_cancellable_new ();
-
-  task = g_task_new (self, self->cancellable, gbp_flatpak_configuration_provider_load_cb, NULL);
+  parent_task = g_task_new (self, cancellable, callback, user_data);
+  task = g_task_new (self, cancellable, gbp_flatpak_configuration_provider_load_cb, g_steal_pointer (&parent_task));
   g_task_run_in_thread (task, gbp_flatpak_configuration_provider_load_worker);
 
   IDE_EXIT;
 }
 
+gboolean
+gbp_flatpak_configuration_provider_load_finish (IdeConfigurationProvider  *provider,
+                                                GAsyncResult              *result,
+                                                GError                   **error)
+{
+  GbpFlatpakConfigurationProvider *self = (GbpFlatpakConfigurationProvider *)provider;
+
+  g_return_val_if_fail (GBP_IS_FLATPAK_CONFIGURATION_PROVIDER (self), FALSE);
+  g_return_val_if_fail (G_IS_TASK (result), FALSE);
+
+  return g_task_propagate_boolean (G_TASK (result), error);
+}
+
 static void
 gbp_flatpak_configuration_provider_unload (IdeConfigurationProvider *provider,
                                            IdeConfigurationManager  *manager)
@@ -1043,11 +1094,6 @@ gbp_flatpak_configuration_provider_unload (IdeConfigurationProvider *provider,
 
   g_clear_pointer (&self->manifest_monitors, g_ptr_array_unref);
 
-  if (self->cancellable != NULL)
-    g_cancellable_cancel (self->cancellable);
-
-  g_clear_object (&self->cancellable);
-
   ide_clear_weak_pointer (&self->manager);
 
   IDE_EXIT;
@@ -1069,7 +1115,8 @@ gbp_flatpak_configuration_provider_init (GbpFlatpakConfigurationProvider *self)
 static void
 configuration_provider_iface_init (IdeConfigurationProviderInterface *iface)
 {
-  iface->load = gbp_flatpak_configuration_provider_load;
+  iface->load_async = gbp_flatpak_configuration_provider_load_async;
+  iface->load_finish = gbp_flatpak_configuration_provider_load_finish;
   iface->unload = gbp_flatpak_configuration_provider_unload;
   iface->save_async = gbp_flatpak_configuration_provider_save_async;
   iface->save_finish = gbp_flatpak_configuration_provider_save_finish;
