@@ -20,9 +20,10 @@
 
 #include "config.h"
 
-#include <egg-counter.h>
+#include <dazzle.h>
 #include <gtk/gtk.h>
 #include <ide.h>
+#include <ide-build-ident.h>
 #include <string.h>
 
 #include "ide-support.h"
@@ -34,7 +35,7 @@ str_to_key (const gchar *str)
 }
 
 static void
-counter_arena_foreach_cb (EggCounter *counter,
+counter_arena_foreach_cb (DzlCounter *counter,
                           gpointer    user_data)
 {
   GString *str = (GString *)user_data;
@@ -43,7 +44,7 @@ counter_arena_foreach_cb (EggCounter *counter,
 
   g_string_append_printf (str,
                           "%s.%s = %"G_GINT64_FORMAT"\n",
-                          category, name, egg_counter_get (counter));
+                          category, name, dzl_counter_get (counter));
 }
 
 gchar *
@@ -63,9 +64,8 @@ ide_get_support_log (void)
 
   g_string_append (str, "[runtime.version]\n");
   g_string_append_printf (str, "version = \"%s\"\n", PACKAGE_VERSION);
-#ifdef COMMIT_ID
-  g_string_append_printf (str, "commit = \"%s\"\n", COMMIT_ID);
-#endif
+  g_string_append_printf (str, "channel = \"%s\"\n", IDE_BUILD_CHANNEL);
+  g_string_append_printf (str, "identifier = \"%s\"\n", IDE_BUILD_IDENTIFIER);
   g_string_append (str, "\n");
 
   /*
@@ -165,7 +165,7 @@ ide_get_support_log (void)
    * Log the counters.
    */
   g_string_append (str, "[runtime.counters]\n");
-  egg_counter_arena_foreach (egg_counter_arena_get_default (),
+  dzl_counter_arena_foreach (dzl_counter_arena_get_default (),
                              counter_arena_foreach_cb, str);
 
   g_string_append (str, "\n\n");
