@@ -21,7 +21,6 @@
 #include <string.h>
 
 #include "application/ide-application-tests.h"
-#include "util/ide-gdk.h"
 
 typedef void (*IndentTestFunc) (IdeContext *context,
                                 GtkWidget  *widget);
@@ -124,7 +123,7 @@ assert_keypress_equal (GtkWidget   *widget,
       while (gtk_events_pending ())
         gtk_main_iteration ();
 
-      event = ide_gdk_synthesize_event_key (window, ch);
+      event = dzl_gdk_synthesize_event_key (window, ch);
       gtk_main_do_event ((GdkEvent *)event);
       gdk_event_free ((GdkEvent *)event);
     }
@@ -171,6 +170,7 @@ gint
 main (gint argc,
       gchar *argv[])
 {
+  static const gchar *required_plugins[] = { "autotools-plugin", "c-pack-plugin", "directory-plugin", NULL };
   IdeApplication *app;
   gint ret;
 
@@ -180,7 +180,7 @@ main (gint argc,
   ide_log_set_verbosity (4);
 
   app = ide_application_new ();
-  ide_application_add_test (app, "/Ide/CIndenter/basic", test_cindenter_basic, NULL);
+  ide_application_add_test (app, "/Ide/CIndenter/basic", test_cindenter_basic, NULL, required_plugins);
   ret = g_application_run (G_APPLICATION (app), argc, argv);
   g_object_unref (app);
 
